// Copyright (c) 2002 David Muse
// See the COPYING file for more information.

#include <rudiments/private/inttypes.h>

#include <sys/types.h>
#include <shadow.h>

#ifdef RUDIMENTS_HAS_THREADS
	#include <rudiments/mutex.h>
#endif
